@@ -71,16 +71,16 @@ static void xml_connect(const gchar *handler_name, GObject *_source,
 {
     JNIEnv *env = ((struct jglade_info *)i)->env;
     jobject obj = ((struct jglade_info *)i)->o;
-    // jclass cls;
-    // jmethodID getWidgetMID;
+    //jclass cls;
+    //jmethodID getWidgetMID;
 
     jstring handler, signal, data;
-    // jobject source, target;
+    //jobject source, target;
 
     if ((*env)->ExceptionCheck(env)) {
 	// debug
 	char* name = handler_name ? (char*)handler_name : "<null>";
-	fprintf(stderr, "xml_connect: skipping %s\n", handler);
+	fprintf(stderr, "xml_connect: skipping %s\n", name);
 	// debug
 	return;
     }
@@ -151,7 +151,7 @@ Java_org_gnu_glade_LibGlade_glade_1xml_1new_1from_1buffer(
 
     if ((*env)->ExceptionCheck(env))
 	return;
-
+	
     (*env)->SetIntField(env, o, gladeFID, (jint)xml);
 }
 
